@@ -61,7 +61,7 @@ var ErrUploadFailed = errors.New("upload failed")
 
 var globalHttpFetcher HTTPFetcher = &http.Client{}
 
-var _ chunks.TableFileStore = (*DoltChunkStore)(nil)
+var _ nbs.TableFileStore = (*DoltChunkStore)(nil)
 var _ nbs.NBSCompressedChunkStore = (*DoltChunkStore)(nil)
 var _ chunks.ChunkStore = (*DoltChunkStore)(nil)
 var _ chunks.LoggingChunkStore = (*DoltChunkStore)(nil)
@@ -110,6 +110,7 @@ type DoltChunkStore struct {
 	repoPath    string
 	repoToken   *atomic.Value // string
 	host        string
+	root        hash.Hash
 	csClient    remotesapi.ChunkStoreServiceClient
 	cache       ChunkCache
 	metadata    *remotesapi.GetRepoMetadataResponse
@@ -146,10 +147,15 @@ func NewDoltChunkStoreFromPath(ctx context.Context, nbf *types.NomsBinFormat, pa
 		return nil, err
 	}
 
+	repoToken := new(atomic.Value)
+	if metadata.RepoToken != "" {
+		repoToken.Store(metadata.RepoToken)
+	}
+
 	cs := &DoltChunkStore{
 		repoId:      repoId,
 		repoPath:    path,
-		repoToken:   new(atomic.Value),
+		repoToken:   repoToken,
 		host:        host,
 		csClient:    csClient,
 		cache:       newMapChunkCache(),
@@ -158,6 +164,10 @@ func NewDoltChunkStoreFromPath(ctx context.Context, nbf *types.NomsBinFormat, pa
 		httpFetcher: globalHttpFetcher,
 		concurrency: defaultConcurrency,
 	}
+	err = cs.loadRoot(ctx)
+	if err != nil {
+		return nil, err
+	}
 	return cs, nil
 }
 
@@ -167,6 +177,7 @@ func (dcs *DoltChunkStore) WithHTTPFetcher(fetcher HTTPFetcher) *DoltChunkStore
 		repoPath:    dcs.repoPath,
 		repoToken:   new(atomic.Value),
 		host:        dcs.host,
+		root:        dcs.root,
 		csClient:    dcs.csClient,
 		cache:       dcs.cache,
 		metadata:    dcs.metadata,
@@ -183,6 +194,7 @@ func (dcs *DoltChunkStore) WithNoopChunkCache() *DoltChunkStore {
 		repoPath:    dcs.repoPath,
 		repoToken:   new(atomic.Value),
 		host:        dcs.host,
+		root:        dcs.root,
 		csClient:    dcs.csClient,
 		cache:       noopChunkCache,
 		metadata:    dcs.metadata,
@@ -200,6 +212,7 @@ func (dcs *DoltChunkStore) WithChunkCache(cache ChunkCache) *DoltChunkStore {
 		repoPath:    dcs.repoPath,
 		repoToken:   new(atomic.Value),
 		host:        dcs.host,
+		root:        dcs.root,
 		csClient:    dcs.csClient,
 		cache:       cache,
 		metadata:    dcs.metadata,
@@ -217,6 +230,7 @@ func (dcs *DoltChunkStore) WithDownloadConcurrency(concurrency ConcurrencyParams
 		repoPath:    dcs.repoPath,
 		repoToken:   new(atomic.Value),
 		host:        dcs.host,
+		root:        dcs.root,
 		csClient:    dcs.csClient,
 		cache:       dcs.cache,
 		metadata:    dcs.metadata,
@@ -796,17 +810,10 @@ func (dcs *DoltChunkStore) Version() string {
 // Rebase brings this ChunkStore into sync with the persistent storage's
 // current root.
 func (dcs *DoltChunkStore) Rebase(ctx context.Context) error {
-	id, token := dcs.getRepoId()
-	req := &remotesapi.RebaseRequest{RepoId: id, RepoToken: token, RepoPath: dcs.repoPath}
-	resp, err := dcs.csClient.Rebase(ctx, req)
+	err := dcs.loadRoot(ctx)
 	if err != nil {
-		return NewRpcError(err, "Rebase", dcs.host, req)
+		return err
 	}
-
-	if resp.RepoToken != "" {
-		dcs.repoToken.Store(token)
-	}
-
 	return dcs.refreshRepoMetadata(ctx)
 }
 
@@ -833,18 +840,21 @@ func (dcs *DoltChunkStore) refreshRepoMetadata(ctx context.Context) error {
 // Root returns the root of the database as of the time the ChunkStore
 // was opened or the most recent call to Rebase.
 func (dcs *DoltChunkStore) Root(ctx context.Context) (hash.Hash, error) {
+	return dcs.root, nil
+}
+
+func (dcs *DoltChunkStore) loadRoot(ctx context.Context) error {
 	id, token := dcs.getRepoId()
 	req := &remotesapi.RootRequest{RepoId: id, RepoToken: token, RepoPath: dcs.repoPath}
 	resp, err := dcs.csClient.Root(ctx, req)
 	if err != nil {
-		return hash.Hash{}, NewRpcError(err, "Root", dcs.host, req)
+		return NewRpcError(err, "Root", dcs.host, req)
 	}
-
 	if resp.RepoToken != "" {
 		dcs.repoToken.Store(resp.RepoToken)
 	}
-
-	return hash.New(resp.RootHash), nil
+	dcs.root = hash.New(resp.RootHash)
+	return nil
 }
 
 // Commit atomically attempts to persist all novel Chunks and update the
@@ -878,6 +888,10 @@ func (dcs *DoltChunkStore) Commit(ctx context.Context, current, last hash.Hash)
 	if err != nil {
 		return false, NewRpcError(err, "Commit", dcs.host, req)
 	}
+	err = dcs.loadRoot(ctx)
+	if err != nil {
+		return false, NewRpcError(err, "Commit", dcs.host, req)
+	}
 
 	return resp.Success, dcs.refreshRepoMetadata(ctx)
 }
@@ -1240,8 +1254,8 @@ func collapseBuffers(bufs [][]byte, length uint64) []byte {
 	return res
 }
 
-func (dcs *DoltChunkStore) SupportedOperations() chunks.TableFileStoreOps {
-	return chunks.TableFileStoreOps{
+func (dcs *DoltChunkStore) SupportedOperations() nbs.TableFileStoreOps {
+	return nbs.TableFileStoreOps{
 		CanRead:  true,
 		CanWrite: true,
 		CanPrune: false,
@@ -1306,7 +1320,7 @@ func (dcs *DoltChunkStore) PruneTableFiles(ctx context.Context) error {
 
 // Sources retrieves the current root hash, a list of all the table files (which may include appendix table files)
 // and a list of only appendix table files
-func (dcs *DoltChunkStore) Sources(ctx context.Context) (hash.Hash, []chunks.TableFile, []chunks.TableFile, error) {
+func (dcs *DoltChunkStore) Sources(ctx context.Context) (hash.Hash, []nbs.TableFile, []nbs.TableFile, error) {
 	id, token := dcs.getRepoId()
 	req := &remotesapi.ListTableFilesRequest{RepoId: id, RepoPath: dcs.repoPath, RepoToken: token}
 	resp, err := dcs.csClient.ListTableFiles(ctx, req)
@@ -1321,8 +1335,8 @@ func (dcs *DoltChunkStore) Sources(ctx context.Context) (hash.Hash, []chunks.Tab
 	return hash.New(resp.RootHash), sourceFiles, appendixFiles, nil
 }
 
-func getTableFiles(dcs *DoltChunkStore, infoList []*remotesapi.TableFileInfo) []chunks.TableFile {
-	tableFiles := make([]chunks.TableFile, 0)
+func getTableFiles(dcs *DoltChunkStore, infoList []*remotesapi.TableFileInfo) []nbs.TableFile {
+	tableFiles := make([]nbs.TableFile, 0)
 	for _, nfo := range infoList {
 		tableFiles = append(tableFiles, DoltRemoteTableFile{dcs, nfo})
 	}
