@@ -45,6 +45,11 @@ func (k prollyKeylessWriter) Map(ctx context.Context) (prolly.Map, error) {
 	return k.mut.Map(ctx)
 }
 
+// ValidateKeyViolations returns nil for keyless writers, because there are no keys, so violations are possible
+func (k prollyKeylessWriter) ValidateKeyViolations(ctx context.Context, sqlRow sql.Row) error {
+	return nil
+}
+
 func (k prollyKeylessWriter) Insert(ctx context.Context, sqlRow sql.Row) error {
 	hashId, value, err := k.tuplesFromRow(ctx, sqlRow)
 	if err != nil {
@@ -175,10 +180,11 @@ func (e secondaryUniqueKeyError) Error() string {
 }
 
 type prollyKeylessSecondaryWriter struct {
-	name    string
-	mut     *prolly.MutableMap
-	primary prollyKeylessWriter
-	unique  bool
+	name          string
+	mut           *prolly.MutableMap
+	primary       prollyKeylessWriter
+	unique        bool
+	prefixLengths []uint16
 
 	keyBld    *val.TupleBuilder
 	prefixBld *val.TupleBuilder
@@ -198,15 +204,44 @@ func (writer prollyKeylessSecondaryWriter) Map(ctx context.Context) (prolly.Map,
 	return writer.mut.Map(ctx)
 }
 
+// ValidateKeyViolations implements the interface indexWriter.
+func (writer prollyKeylessSecondaryWriter) ValidateKeyViolations(ctx context.Context, sqlRow sql.Row) error {
+	return nil
+}
+
+// trimKeyPart will trim entry into the sql.Row depending on the prefixLengths
+func (writer prollyKeylessSecondaryWriter) trimKeyPart(to int, keyPart interface{}) interface{} {
+	var prefixLength uint16
+	if len(writer.prefixLengths) > to {
+		prefixLength = writer.prefixLengths[to]
+	}
+	if prefixLength != 0 {
+		switch kp := keyPart.(type) {
+		case string:
+			if prefixLength > uint16(len(kp)) {
+				prefixLength = uint16(len(kp))
+			}
+			keyPart = kp[:prefixLength]
+		case []uint8:
+			if prefixLength > uint16(len(kp)) {
+				prefixLength = uint16(len(kp))
+			}
+			keyPart = kp[:prefixLength]
+		}
+	}
+	return keyPart
+}
+
 // Insert implements the interface indexWriter.
 func (writer prollyKeylessSecondaryWriter) Insert(ctx context.Context, sqlRow sql.Row) error {
 	for to := range writer.keyMap {
 		from := writer.keyMap.MapOrdinal(to)
-		if err := index.PutField(ctx, writer.mut.NodeStore(), writer.keyBld, to, sqlRow[from]); err != nil {
+		keyPart := writer.trimKeyPart(to, sqlRow[from])
+		if err := index.PutField(ctx, writer.mut.NodeStore(), writer.keyBld, to, keyPart); err != nil {
 			return err
 		}
 		if to < writer.prefixBld.Desc.Count() {
-			if err := index.PutField(ctx, writer.mut.NodeStore(), writer.prefixBld, to, sqlRow[from]); err != nil {
+			if err := index.PutField(ctx, writer.mut.NodeStore(), writer.prefixBld, to, keyPart); err != nil {
 				return err
 			}
 		}
@@ -275,7 +310,8 @@ func (writer prollyKeylessSecondaryWriter) Delete(ctx context.Context, sqlRow sq
 
 	for to := range writer.keyMap {
 		from := writer.keyMap.MapOrdinal(to)
-		if err := index.PutField(ctx, writer.mut.NodeStore(), writer.keyBld, to, sqlRow[from]); err != nil {
+		keyPart := writer.trimKeyPart(to, sqlRow[from])
+		if err := index.PutField(ctx, writer.mut.NodeStore(), writer.keyBld, to, keyPart); err != nil {
 			return err
 		}
 	}
