@@ -61,11 +61,19 @@ func (s *nomsDsTestSuite) TestNomsDs() {
 
 	cs, err := nbs.NewLocalStore(context.Background(), types.Format_Default.VersionString(), dir, clienttest.DefaultMemTableSize, nbs.NewUnlimitedMemQuotaProvider())
 
-	golden1 := "oetp3jigkp5pid2f5c4mknpo17mso31b"
-	golden2 := "tsbj1qq88llk3k8qqqb5n3188sbpiu7r"
-	if types.Format_Default == types.Format_DOLT_DEV {
+	var golden1, golden2 string
+	switch types.Format_Default {
+	case types.Format_DOLT:
 		golden1 = "c7g244286kom2a1326kkgs85pi97cjs7"
 		golden2 = "rn7dsl1146qr2n4chtg41n24n0jqgnte"
+	case types.Format_LD_1:
+		golden1 = "oetp3jigkp5pid2f5c4mknpo17mso31b"
+		golden2 = "tsbj1qq88llk3k8qqqb5n3188sbpiu7r"
+	case types.Format_DOLT_DEV:
+		golden1 = "c7g244286kom2a1326kkgs85pi97cjs7"
+		golden2 = "rn7dsl1146qr2n4chtg41n24n0jqgnte"
+	default:
+		s.Fail("no golden values exist for NBF %s", types.Format_Default.VersionString())
 	}
 
 	s.NoError(err)
