@@ -22,9 +22,14 @@
 package hash
 
 import (
+	"math/rand"
 	"testing"
 
+	"golang.org/x/crypto/blake2b"
+
 	"github.com/stretchr/testify/assert"
+	"github.com/zeebo/blake3"
+	"github.com/zeebo/xxh3"
 )
 
 func TestParseError(t *testing.T) {
@@ -144,3 +149,42 @@ func TestCompareGreater(t *testing.T) {
 	assert.False(r0.Compare(r2) > 0)
 	assert.True(r2.Compare(r0) > 0)
 }
+
+func init() {
+	avg, std := 4096.0, 1024.0
+	for i := range benchData {
+		sz := int(rand.NormFloat64()*std + avg)
+		benchData[i] = make([]byte, sz)
+		rand.Read(benchData[i])
+	}
+}
+
+var benchData [512][]byte
+
+func BenchmarkSha512(b *testing.B) {
+	for i := 0; i < b.N; i++ {
+		j := i % len(benchData)
+		_ = Of(benchData[j])
+	}
+}
+
+func BenchmarkBlake2(b *testing.B) {
+	for i := 0; i < b.N; i++ {
+		j := i % len(benchData)
+		_ = blake2b.Sum256(benchData[j])
+	}
+}
+
+func BenchmarkBlake3(b *testing.B) {
+	for i := 0; i < b.N; i++ {
+		j := i % len(benchData)
+		_ = blake3.Sum256(benchData[j])
+	}
+}
+
+func BenchmarkXXHash(b *testing.B) {
+	for i := 0; i < b.N; i++ {
+		j := i % len(benchData)
+		_ = xxh3.Hash128(benchData[j])
+	}
+}
