@@ -455,10 +455,10 @@ func NewGCSStore(ctx context.Context, nbfVerStr string, bucketName, path string,
 func NewBSStore(ctx context.Context, nbfVerStr string, bs blobstore.Blobstore, memTableSize uint64, q MemoryQuotaProvider) (*NomsBlockStore, error) {
 	cacheOnce.Do(makeGlobalCaches)
 
-	mm := makeManifestManager(blobstoreManifest{"manifest", bs})
+	mm := makeManifestManager(blobstoreManifest{bs})
 
 	p := &blobstorePersister{bs, s3BlockSize, q}
-	return newNomsBlockStore(ctx, nbfVerStr, mm, p, q, inlineConjoiner{defaultMaxTables}, memTableSize)
+	return newNomsBlockStore(ctx, nbfVerStr, mm, p, q, noopConjoiner{}, memTableSize)
 }
 
 func NewLocalStore(ctx context.Context, nbfVerStr string, dir string, memTableSize uint64, q MemoryQuotaProvider) (*NomsBlockStore, error) {
