@@ -30,6 +30,12 @@ const patchBufferSize = 1024
 // of the tuples, or register a conflict if such a merge is not possible.
 type CollisionFn func(left, right Diff) (Diff, bool)
 
+type MergeStats struct {
+	Adds          int
+	Modifications int
+	Removes       int
+}
+
 // ThreeWayMerge implements a three-way merge algorithm using |base| as the common ancestor, |right| as
 // the source branch, and |left| as the destination branch. Both |left| and |right| are diff'd against
 // |base| to compute merge patches, but rather than applying both sets of patches to |base|, patches from
@@ -43,16 +49,16 @@ func ThreeWayMerge[K ~[]byte, O Ordering[K], S message.Serializer](
 	collide CollisionFn,
 	order O,
 	serializer S,
-) (final Node, err error) {
+) (final Node, stats MergeStats, err error) {
 
 	ld, err := DifferFromRoots[K](ctx, ns, ns, base, left, order)
 	if err != nil {
-		return Node{}, err
+		return Node{}, MergeStats{}, err
 	}
 
 	rd, err := DifferFromRoots[K](ctx, ns, ns, base, right, order)
 	if err != nil {
-		return Node{}, err
+		return Node{}, MergeStats{}, err
 	}
 
 	eg, ctx := errgroup.WithContext(ctx)
@@ -65,7 +71,7 @@ func ThreeWayMerge[K ~[]byte, O Ordering[K], S message.Serializer](
 				err = cerr
 			}
 		}()
-		err = sendPatches(ctx, ld, rd, patches, collide)
+		stats, err = sendPatches(ctx, ld, rd, patches, collide)
 		return
 	})
 
@@ -76,10 +82,10 @@ func ThreeWayMerge[K ~[]byte, O Ordering[K], S message.Serializer](
 	})
 
 	if err = eg.Wait(); err != nil {
-		return Node{}, err
+		return Node{}, MergeStats{}, err
 	}
 
-	return final, nil
+	return final, stats, nil
 }
 
 // patchBuffer implements MutationIter. It consumes Diffs
@@ -128,7 +134,7 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 	l, r Differ[K, O],
 	buf patchBuffer,
 	cb CollisionFn,
-) (err error) {
+) (stats MergeStats, err error) {
 	var (
 		left, right Diff
 		lok, rok    = true, true
@@ -139,7 +145,7 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 		err, lok = nil, false
 	}
 	if err != nil {
-		return err
+		return MergeStats{}, err
 	}
 
 	right, err = r.Next(ctx)
@@ -147,7 +153,7 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 		err, rok = nil, false
 	}
 	if err != nil {
-		return err
+		return MergeStats{}, err
 	}
 
 	for lok && rok {
@@ -161,30 +167,32 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 				err, lok = nil, false
 			}
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
 
 		case cmp > 0:
 			err = buf.sendPatch(ctx, right)
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
+			updateStats(right, &stats)
 
 			right, err = r.Next(ctx)
 			if err == io.EOF {
 				err, rok = nil, false
 			}
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
 
 		case cmp == 0:
 			resolved, ok := cb(left, right)
 			if ok {
 				err = buf.sendPatch(ctx, resolved)
+				updateStats(right, &stats)
 			}
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
 
 			left, err = l.Next(ctx)
@@ -192,7 +200,7 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 				err, lok = nil, false
 			}
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
 
 			right, err = r.Next(ctx)
@@ -200,30 +208,42 @@ func sendPatches[K ~[]byte, O Ordering[K]](
 				err, rok = nil, false
 			}
 			if err != nil {
-				return err
+				return MergeStats{}, err
 			}
 		}
 	}
 
 	if lok {
 		// already in left
-		return nil
+		return stats, nil
 	}
 
 	for rok {
 		err = buf.sendPatch(ctx, right)
 		if err != nil {
-			return err
+			return MergeStats{}, err
 		}
+		updateStats(right, &stats)
 
 		right, err = r.Next(ctx)
 		if err == io.EOF {
 			err, rok = nil, false
 		}
 		if err != nil {
-			return err
+			return MergeStats{}, err
 		}
 	}
 
-	return nil
+	return stats, nil
+}
+
+func updateStats(right Diff, stats *MergeStats) {
+	switch right.Type {
+	case AddedDiff:
+		stats.Adds++
+	case RemovedDiff:
+		stats.Removes++
+	case ModifiedDiff:
+		stats.Modifications++
+	}
 }
