@@ -14,9 +14,7 @@
 
 package main
 
-import (
-	"testing"
-)
+import "testing"
 
 func TestConfig(t *testing.T) {
 	RunTestsFile(t, "tests/sql-server-config.yaml")
